(e) [Reserved].  For further guidance, see §1.1563-3T(e)(1). Par. 50.  Section 1.1563-3T is added to read as follows:
§1.1563-3T Rules for determining stock ownership (temporary).

(a) through (d)(2)(iii) [Reserved].  For further guidance, see §1.1563-3(a)
through (d)(2)(iii). (iv) Statement. If the application of paragraph (d)(2)(ii) or (iii) of §1.1563-3 does not result in a corporation being treated as a component member of only one controlled group of corporations on a December 31, then such corporation will be treated as a component member of only one such group on such date.  Such corporation may elect the group in which it is to be included by including on or with its income tax return a statement entitled, “STATEMENT TO ELECT CONTROLLED GROUP PURSUANT TO §1.1563-3T(d)(2)(iv).”  The statement must include--

(A) A description of each of the controlled groups in which the corporation
could be included.  The description must include the name and employer identification number of each component member of each such group and the stock ownership of the component members of each such group; and

(B) The following representation: [INSERT NAME AND EMPLOYER
IDENTIFICATION NUMBER OF CORPORATION] ELECTS TO BE TREATED AS A COMPONENT MEMBER OF THE [INSERT DESIGNATION OF GROUP].

(v) Election-- (A) Election filed.  An election filed under paragraph (d)(2)(iv) of
this section is irrevocable and effective until paragraph (d)(2)(ii) or (iii) of §1.1563-3 applies or until a change in the stock ownership of the corporation results in

termination of membership in the controlled group in which such corporation has been included.

(B) Election not filed. In the event no election is filed in accordance with the
provisions of paragraph (d)(2)(iv)  of this section, then the Internal Revenue Service will determine the group in which such corporation is to be included.  Such determination will be binding for all subsequent years unless the corporation files a valid election with respect to any such subsequent year or until a change in the stock ownership of the corporation results in termination of membership in the controlled group in which such corporation has been included.

(d)(3) [Reserved].  For further guidance, see §1.1563-3(d)(3).
(e) Effective date-- (1) Applicability date. This section applies to any original
Federal income tax return (including any amended return filed on or before the due date (including extensions) of such original return) timely filed on or after May 30,

2006.
(2) Expiration date.  The applicability of this section will expire on May 26,
2009. Par. 51.  Section 1.6012-2 is amended by revising paragraph (c) and adding paragraph (k) to read as follows: §1.6012-2 Corporations required to make returns of income.
* * * * *
(c) [Reserved]. For further guidance, see §1.6012-2T(c).
* * * * *
(k) [Reserved].  For further guidance, see §1.6012-2T(k)(1).

Par. 52.  Section 1.6012-2T is added to read as follows: §1.6012-2T Corporations required to make returns of income (temporary).

(a) through (b) [Reserved].  For further guidance, see §1.6012-2(a) through
(b).
(c) Insurance companies-- (1) Domestic life insurance companies-- (i)  In
general.  A life insurance company subject to tax under section 801 shall make a return on Form 1120L. Except as provided in paragraph (c)(4) of this section, such company shall file with its return--

(A) A copy of its annual statement which shows the reserves used by the
company in computing the taxable income reported on its return; and

(B) A copy of Schedule A (real estate) and of Schedule D (bonds and stocks),
or any successor thereto, of such annual statement. (ii) Mutual savings banks.  Mutual savings banks conducting life insurance business and meeting the requirements of section 594 are subject to partial tax computed on Form 1120 and partial tax computed on Form 1120L.  The Form 1120L is attached as a schedule to Form 1120, together with the annual statement and schedules required to be filed with Form 1120L.

(2) Domestic nonlife insurance companies.  Every domestic insurance
company other than a life insurance company shall make a return on Form 1120PC. This includes organizations described in section 501(m)(1) that provide commercial- type insurance and organizations described in section 833.  Except as provided in paragraph (c)(4) of this section, such company shall file with its return a copy of its

annual statement (or a pro forma annual statement), including the underwriting and investment exhibit for the year covered by such return.

(3) Foreign insurance companies.  The provisions of paragraphs (c)(1) and
(c)(2) of this section concerning the returns and statements of insurance companies subject to tax under section 801 or section 831 also apply to foreign insurance companies subject to tax under those sections, except that the copy of the annual statement required to be submitted with the return shall, in the case of a foreign insurance company that is not required to file an annual statement, be a copy of the pro forma annual statement relating to the United States business of such company.
(4) Exception for insurance companies filing their Federal income tax returns
electronically.  If an insurance company described in paragraph (c)(1), (c)(2), or

(c)(3) of this section files its Federal income tax return electronically, it should not include on or with such return its annual statement (or pro forma annual statement), or any portion thereof.  Such statement must be available at all times for inspection by authorized Internal Revenue Service officers or employees and retained for so long as such statements may be material in the administration of any internal revenue law.  See §1.6001-1(e).
(5) Definition.  For purposes of this section, the term annual statement means
the annual statement, the form of which is approved by the National Association of Insurance Commissioners (NAIC), which is filed by an insurance company for the year with the insurance departments of States, Territories, and the District of

Columbia.  The term annual statement also includes a pro forma annual statement if the insurance company is not required to file the NAIC annual statement.

(d) through (j) [Reserved].  For further guidance, see §1.6012-2(d) through (j).
(k) Effective date-- (1) Applicability date. This section applies to any original
Federal income tax return (including any amended return filed on or before the due date (including extensions) of such original return) timely filed on or after May 30,

2006.
(2) Expiration date.  The applicability of this section will expire on May 26,
2009. Par. 53.  For each entry in the “Location” column of the following table, remove the language in the “Remove” column and add the language in the “Add” column in its place: Location Remove Add The last sentence of the The following rules shall The rules described in introductory text to be applicable in paragraph (a) of §1.302- §1.302-4 determining whether the 4T and in paragraphs (b)
specific requirements of through (g) of this section section 302(c)(2) are apply in determining met: whether the specific requirements of section 302(c)(2) are met. §1.338(h)(10)-1(f) §1.331-1(d), and §1.332-§1.331-1T(d) and §1.332- 6 6T

| The last sentence of    | paragraph (a)(2)(ii) of this | paragraph (a) of §1.382-  |
| ----------------------- | ---------------------------- | ------------------------- |
| §1.382-2T(h)(4)(vi)(B)  | section                      | 11T                       |
| The first sentence of   | §1.382-2T(a)(2)(ii)          | §1.382-11T(a)             |

§1.382-6(b)(2)(i) The second sentence of paragraph (c) of this paragraphs (c)(1), (c)(3), §1.382-8(a) section (c)(4) and (c)(5) of this section and paragraph

(c)(2) of §1.382-8T

The third sentence of §1.382-8(a)

§1.382-8(c)(3) The first sentence of §1.382-8(c)(4)

§1.382-8(c)(5)

The fifth sentence of §1.382-8(f)

§1.382-8(g), Example

(1)(b)(2) The second sentence of §1.382-8(g), Example
(1)(c)
paragraph (c) of this section

paragraph (c)(2) of this section paragraphs (c)(1), (2), and (3) of this section

this paragraph (c)

paragraphs (c)(1), (c)(3),

(c)(4) and (c)(5) of this section and paragraph
(c)(2) of §1.382-8T paragraph (c)(2) of §1.382-8T paragraphs (c)(1) and
(c)(3) of this section and paragraph (c)(2) of §1.382-8T paragraphs (c)(1), (c)(3),
(c)(4), and (c)(5) of this section, and paragraph
(c)(2) of §1.382-8T paragraphs (c)(1), (c)(3),
(c)(4), and (c)(5) of this section, and paragraph
(c)(2) of §1.382-8T paragraphs (c)(1), (c)(3),
(c)(4), and (c)(5) of this section, and paragraph
(c)(2) of §1.382-8T paragraphs (c)(1), (c)(3),
(c)(4), and (c)(5) of this section, and paragraph
(c)(2) of §1.382-8T

| §1.382-8(g), Example  | paragraph (c)(2) of this | paragraph (c)(2) of |
| --------------------- | ------------------------ | ------------------- |
| The first sentence of | paragraph (c)(2) of this | paragraph (c)(2) of |
| §1.382-8(g), Example  | section                  | §1.382-8T           |

(2)(c) section §1.382-8T

(2)(e)

| §1.382-8(g), Example  | paragraph (c)(2) of this  | paragraph (c)(2) of      |
| --------------------- | ------------------------- | ------------------------ |
| §1.382-8(g), Example  | paragraphs (c)(1) and (2) | paragraph (c)(1) of this |

(3)(b) section §1.382-8T
(3)(c)(1)(B) of this section section and paragraph

The second sentence of §1.382-8(g), Example

(4)(c) The second sentence of §1.382-8(g), Example
(5)(c)
paragraph (c) of this section

paragraph (c) of this section

paragraph (c) of this section

paragraph (c)(2) of this section paragraph (c)(2) of this section

(c)(2) of §1.382-8T paragraph (c)(2) of §1.382-8T paragraph (c)(2) of §1.382-8T

| The first sentence of   | paragraph (b)(4)(iv) of | paragraph (b)(4)(iv) of |
| ----------------------- | ----------------------- | ----------------------- |
| §1.1502-32(b)(4)(v)(A)  | this section            | §1.1502-32T             |
| The first sentence of   | paragraph (b)(4)(iv) of | paragraph (b)(4)(iv) of |
| §1.1502-32(b)(4)(v)(B)  | this section            | §1.1502-32T             |

§1.1502-35(c)(4)(ii)(B) §1.1502-76(b)(2)(ii)(D) §1.1502-76(b)(2)(ii)(A)(2) paragraph (b)(2)(ii)(D) of this section §1.1502-92(e)(1) §1.382-2T(a)(2)(ii) The first sentence of §1.382-2T(a)(2)(ii) §1.1502-92(e)(2) The first sentence of §1.382-2T(a)(2)(ii) §1.1502-94(d) The second sentence of §1.382-2T(a)(2)(ii) §1.1502-94(d)

| The last sentence of  | paragraph (f) of this    | paragraph (f) of §1.1502-  |
| --------------------- | ------------------------ | -------------------------- |
| §1.1502-95(b)(3)      | section                  | 95T                        |
| The last sentence of  | subdivision (ii) of this | paragraph (c)(2)(i) of     |
| §1.1563-1(c)(2)(iv),  | subparagraph             | §1.1563-1T                 |

Example (1) The last sentence of §1.1563-1(c)(2)(iv), Example (1) The third sentence of §1.1563-1(c)(2)(iv), Example (2) The third sentence of §1.1563-1(c)(2)(iv), Example (2)

The last sentence of §1.1563-1(c)(2)(iv), Example (2) The second sentence of §1.1563-3(d)(2)(i)

the district director with audit jurisdiction of N’s return subdivision (iii) of this subparagraph the district director with audit jurisdiction of the return of the corporation whose taxable year ends on the earliest date district director

subdivisions (ii), (iii), and (iv) of this subparagraph

§1.1502-76T(b)(2)(ii)(D) paragraph (b)(2)(ii)(D) of §1.1502-76T §1.382-11T(a) §1.382-11T(a) §1.382-11T(a) §1.382-11T(a)

| The first sentence of | §1.332-6(b), 1.368-3(a),  | §1.332-6T(a), §1.368-   |
| --------------------- | ------------------------- | ----------------------- |
| §1.6043-2(a)          | or 1.1081-11              | 3T(a), or §1.1081-11T   |
| The first sentence of | §1.6012-2                 | paragraphs (a), (b) and |

§301.6011-5T(a) (twice)

the Internal Revenue Service paragraph (c)(2)(ii) of §1.1563-1T the Internal Revenue Service

Internal Revenue Service

paragraphs (d)(2)(ii) and (iii) of this section, and paragraph (d)(2)(iv) of §1.1563-3T

(d) through (j) of §1.6012- 2, and paragraph (c) of §1.6012-2T

PART 602--OMB CONTROL NUMBERS UNDER THE PAPERWORK REDUCTION ACT Par. 54.  The authority citation for part 602 continues to read as follows: Authority:  26 U.S.C. 7805. Par. 55.  In §602.101, paragraph (b) is amended to read as follows:

1.  The following entries to the table are removed:
§602.101 OMB Control numbers.

* * * * *
(b) * * *
CFR part or section where Current OMB identified or described control No.

* * * * *
1.332-6………………………………………………………………….    1545-2019
1.382-11………………………………………………………………..     1545-2019
1.351-3………………………………………………………………….    1545-2019
1.355-5………………………………………………………………….    1545-2019
1.368-3………………………………………………………………….    1545-2019
1.1081-11……………………………………………………………….    1545-2019
* * * * * **______________________________________________________________**
2.  The following entries are added in numerical order to the table:
§602.101 OMB Control numbers.

* * * * *
(b) * * *
CFR part or section where Current OMB identified or described control No.

* * * * *
1.302-2T…………………………………………………………………   1545-2019
1.302-4T…………………………………………………………………   1545-2019

1.331-1T…………………………………………………………………   1545-2019
1.332-6T………………………………………………………………...    1545-2019
1.338-10T……………………………………………………………….    1545-2019
1.351-3T…………………………………………………………………   1545-2019
1.355-5T…………………………………………………………………   1545-2019
1.368-3T…………………………………………………………………   1545-2019
1.381(b)-1T……………………………………………………………..    1545-2019
1.382-8T…………………………………………………………………   1545-2019
1.382-11T……………………………………………………………….    1545-2019
1.1081-11T………………………………………………………………   1545-2019
1.1221-2T………………………………………………………………..   1545-2019
1.1502-13T………………………………………………………………   1545-2019
1.1502-31T………………………………………………………………   1545-2019
1.1502-32T………………………………………………………………   1545-2019
1.1502-33T………………………………………………………………   1545-2019
1.1502-35T………………………………………………………………   1545-2019
1.1502-76T………………………………………………………………   1545-2019
1.1502-95T………………………………………………………………   1545-2019
1.1563-1T………………………………………………………………..   1545-2019

1.1563-3T………………………………………………………………..   1545-2019
1.6012-2T………………………………………………………………..   1545-2019
* * * * * Mark E. Matthews
Deputy Commissioner for Services and Enforcement.

Approved:  May 19, 2006 Eric Solomon Acting Deputy Assistant Secretary of the Treasury (Tax Policy).

